import fs from 'fs/promises';
import path from 'path';
import { createFilter } from '@rollup/pluginutils';
import cheerio from 'cheerio';

const virtualExtension = ".htmlvue.vue";
const htmlvue = (options = {}) => {
  const filter = createFilter(
    options.include ?? "**/*.html",
    options.exclude
  );
  return {
    name: "htmlvue",
    // If it matches a resource, rename it with the .vue extension
    async resolveId(id, importer) {
      if (!path.isAbsolute(id)) {
        const resolved = await this.resolve(id, importer, { skipSelf: true });
        if (resolved && !resolved.external) {
          id = resolved.id;
        }
      }
      if (!filter(id)) {
        return null;
      }
      return `${id}${virtualExtension}`;
    },
    // Create SFC
    async load(id) {
      if (!id.endsWith(virtualExtension)) {
        return null;
      }
      const html = await fs.readFile(id.replace(virtualExtension, ""));
      let $ = cheerio.load(html, { xmlMode: true });
      if ($.root().children().length > 1) {
        $ = cheerio.load(`<div>${$.xml()}</div>`, { xmlMode: true });
      }
      const rootElement = $.root().children().first();
      if (options.vOnce) {
        rootElement.attr("v-once", "");
      }
      if (options.vPre) {
        rootElement.attr("v-pre", "");
      }
      if (options.inheritListeners) {
        rootElement.attr("v-on", "$listeners");
      }
      return `<template${options.functional ? " functional" : ""}>${$.xml(rootElement)}</template>`;
    }
  };
};

export { htmlvue as default };
